pub struct StrictFinitePolicy<ScalarType: Sized, const PRECISION: u32>(/* private fields */);Expand description
A validation policy that checks for strict finiteness.
For floating-point types (ScalarType = f64, ScalarType = rug::Float), this policy ensures that the value is:
- Not NaN (Not a Number).
- Not positive or negative Infinity.
- Not subnormal (for
f64). Whilerug::Floatmaintains its specified precision rather than having distinct subnormal representation in the IEEE 754 sense, this policy will also rejectrug::Floatvalues that are classified asFpCategory::Subnormal(e.g., results of underflow that are tiny but not exactly zero).
For complex types (ScalarType = Complex<f64>, ScalarType = rug::Complex), this policy applies
the strict finiteness check to both the real and imaginary parts.
This struct is a Zero-Sized Type (ZST) and uses PhantomData to associate
with the ScalarType it validates.