pub enum ATanComplexInputErrors<RawComplex: RawComplexTrait> {
ArgumentIsPole {
value: RawComplex,
backtrace: Backtrace,
},
InvalidArgument {
source: <RawComplex as RawScalarTrait>::ValidationErrors,
},
}Expand description
Errors that can occur during the input validation phase when attempting to compute the arctangent of a complex number.
This enum is used as a source for the Input variant of ATanComplexErrors.
It is generic over RawComplex, which must implement RawComplexTrait.
This enum addresses failures in the initial validation of the input complex
number (e.g., components being NaN, Infinity, or subnormal) or if the
argument is a pole for the complex arctangent function (e.g., 0 +/- 1i).
Variants
ArgumentIsPole
The input complex number is a pole for the arctangent function (e.g., i or -i).
The complex arctangent function is undefined at these points.
Fields
value: RawComplexThe argument value that is a pole.
InvalidArgument
The argument of the function is invalid due to failing general validation checks.
This variant indicates that the argument of the function is invalid w.r.t. the chosen validation policy (e.g. NaN, Infinity). It includes the source error that occurred during validation.
Fields
source: <RawComplex as RawScalarTrait>::ValidationErrorsThe source error that occurred during validation.