pub struct NaiveSum<T>(/* private fields */);Expand description
Naive (plain +=) accumulator.
This strategy keeps a single running sum and updates it with standard floating-point addition. It has minimal overhead and is usually the fastest option, but it may lose small addends when values have very different magnitudes.
In norm routines this is used by the default APIs such as
crate::algorithms::vector_norms::vector_norm_l1,
crate::algorithms::vector_norms::vector_norm_l2, and
crate::algorithms::vector_norms::vector_norm_l2_sq.
Example
use num_valid::algorithms::accumulators::*;
let mut naive = NaiveSum::<f64>::new();
naive.push(1.0);
naive.push(2.0);
naive.push(3.0);
assert_eq!(naive.result(), 6.0);Trait Implementations
Sourceimpl<T: FpScalar> Accumulator for NaiveSum<T>
impl<T: FpScalar> Accumulator for NaiveSum<T>
Sourcefn new_sequential<I>(values: I) -> Selfwhere
I: IntoIterator<Item = Self::Input>,
fn new_sequential<I>(values: I) -> Selfwhere
I: IntoIterator<Item = Self::Input>,
Creates a new accumulator by sequentially adding all values from
values. Read moreSourcefn new_parallel<I>(values: I) -> Self
fn new_parallel<I>(values: I) -> Self
Builds an accumulator by processing a parallel iterator. Read more
Sourceimpl<T: FpScalar> SumAccumulator for NaiveSum<T>
impl<T: FpScalar> SumAccumulator for NaiveSum<T>
Sourcefn rescale_by(&mut self, r: &T)
fn rescale_by(&mut self, r: &T)
Multiply the entire accumulated sum by
r.Auto Trait Implementations
impl<T> Freeze for NaiveSum<T>where
T: Freeze,
impl<T> RefUnwindSafe for NaiveSum<T>where
T: RefUnwindSafe,
impl<T> Send for NaiveSum<T>where
T: Send,
impl<T> Sync for NaiveSum<T>where
T: Sync,
impl<T> Unpin for NaiveSum<T>where
T: Unpin,
impl<T> UnsafeUnpin for NaiveSum<T>where
T: UnsafeUnpin,
impl<T> UnwindSafe for NaiveSum<T>where
T: UnwindSafe,